<template>
	<section class="productslider">
		<h2 v-if="title">{{ title }}</h2>
		<div class="row">
			<swiper :options="swiperAwOptions">
				<swiper-slide v-for="product in collection" :key="product.entity_id">
					<product-box
						is-product-slider
						:is-loading="isLoading"
						:item-list="cmpItemList"
						:product="product"
						:show-add-to-cart="showAddToCart"
						:translations="translations"
						:view="view"
						@start-loading="startLoading()"
					/>
				</swiper-slide>
				<div class="swiper-scrollbar" slot="scrollbar"></div>
			</swiper>
		</div>
	</section>
</template>

<script>
	module.exports = {
		data() {
			return {
				iconUrl,
				jsBaseUrl,
				loading: false,
				swiperAwOptions: {
					direction: "horizontal",
					spaceBetween: 0,
					slidesPerView: 4,
					watchOverflow: true,
					autoplay: {
						delay: 10000,
					},
					scrollbar: {
						el: ".swiper-scrollbar",
						hide: true,
						draggable: true,
					},
					breakpoints: {
						320: {
							slidesPerView: 1,
						},
						576: {
							slidesPerView: 2,
						},
						768: {
							slidesPerView: 3,
						},
						991: {
							slidesPerView: 4,
						},
					},
				},
				swiperAwMobOptions: {
					direction: "horizontal",
					slidesPerView: 1,
					watchOverflow: true,
					autoplay: {
						delay: 4200,
					},
					pagination: {
						el: ".swiper-pagination-aw",
						clickable: true,
					},
					navigation: {
						nextEl: ".swiper-button-next-aw-mob",
						prevEl: ".swiper-button-prev-aw-mob",
					},
				},
				translations: {},
				view: "grid",
			};
		},
		props: {
			collection: Array,
			isLoading: Boolean,
			itemList: Object,
			showAddToCart: Boolean,
			title: String,
		},
		components: {
			ProductBox: `url:${jsBaseUrl}vue/ok_components/catalog/ProductBox.vue?v=${smsGeneralJsVersion}`,
		},
		methods: {
			getTranslations() {
				this.$http
					.get("related/index/getProductSliderTranslations", {})
					.then(response => {
						this.translations = response.body;
					});
			},
			startLoading() {
				this.loading = true;
			},
		},
		computed: {
			cmpItemList() {
				return {
					item_list_id: this.itemList?.item_list_id || "product_slider",
					item_list_name: this.itemList?.item_list_name || "Product slider",
				};
			},
		},
		mounted() {
			this.getTranslations();
		},
	};
</script>

<style scoped>
	.swiper-container {
		min-height: 250px;
	}
</style>
